# anotherpdfmerger

This is a small program to concatenate PDFs and add bookmarks where the
start of each PDF begins. The bookmarks have the same filename as the
PDF, minus the extension.

There are a few of these programs around, but none that had the exact
formatting I wanted. So here's another one.
